@@ -1,4 +1,4 @@
-package Tk::AppWindow::Plugins::Console;
+package App::Codit::Plugins::Console;
 
 =head1 NAME
 
@@ -8,6 +8,8 @@ App::Codit::Plugins::Console - plugin for App::Codit
 
 use strict;
 use warnings;
+use vars qw( $VERSION );
+$VERSION = 0.02;
 
 use base qw( Tk::AppWindow::BaseClasses::Plugin );
 
